@@ -112,6 +112,12 @@ def upload_xlsx_to_gcs(
     return final_object
 
 
+# see also: https://github.com/CIMAC-CIDC/cidc-cloud-functions/blob/2e27faca1062adf8143a7c33e0c382e833fd0726/functions/uploads.py#L173
+# # there is a separate permissions system that applies the expiring IAM role
+# # `CIDC_biofx` to the `cidc-dfci-biofx-[wes/rna]@ds` emails using a `trial/assay` prefix
+# # while removing any existing perm for the same prefix
+
+
 def grant_upload_access(user_email: str):
     """
     Grant a user upload access to the GOOGLE_UPLOAD_BUCKET. Upload access
@@ -217,7 +223,7 @@ def grant_download_access(
     storage_client = _get_storage_client()
     for prefix in prefixes:
         for blob in storage_client.list_blobs(GOOGLE_ACL_DATA_BUCKET, prefix=prefix):
-            blob.acl.grant_reader(user_email)
+            blob.acl.user(user_email).grant_reader()
 
 
 def revoke_download_access(
@@ -238,9 +244,10 @@ def revoke_download_access(
     removed_from = []
     for prefix in prefixes:
         for blob in storage_client.list_blobs(GOOGLE_ACL_DATA_BUCKET, prefix=prefix):
-            blob.acl.revoke_owner(user_email)
-            blob.acl.revoke_writer(user_email)
-            blob.acl.revoke_reader(user_email)
+            blob_user = blob.acl.user(user_email)
+            blob_user.revoke_owner()
+            blob_user.revoke_writer()
+            blob_user.revoke_reader()
             removed_from.append(f"gs://{blob.name}")
 
 
@@ -310,13 +317,13 @@ def grant_gcs_access(
         try:
             if role == "owner":
                 logger.warning("Granting OWNER on {obj} to {user_email}")
-                obj.acl.grant_owner(user_email)
+                obj.acl.user(user_email).grant_owner()
             elif role == "writer":
                 logger.info("Granting WRITER on {obj} to {user_email}")
-                obj.acl.grant_writer(user_email)
+                obj.acl.user(user_email).grant_writer()
             else:  # role == "reader"
                 logger.info("Granting READER on {obj} to {user_email}")
-                obj.acl.grant_reader(user_email)
+                obj.acl.user(user_email).grant_reader()
         except Exception as e:
             logger.error(str(e))
             raise e
@@ -359,9 +366,10 @@ def revoke_all_download_access(user_email: str):
     # https://googleapis.dev/python/storage/latest/client.html#google.cloud.storage.client.Client.list_blobs
     storage_client = _get_storage_client()
     for blob in storage_client.list_blobs(GOOGLE_ACL_DATA_BUCKET):
-        blob.acl.revoke_owner(user_email)
-        blob.acl.revoke_writer(user_email)
-        blob.acl.revoke_reader(user_email)
+        blob_user = blob.acl.user(user_email)
+        blob_user.revoke_owner()
+        blob_user.revoke_writer()
+        blob_user.revoke_reader()
 
 
 user_member = lambda email: f"user:{email}"
